@@ -9,6 +9,6 @@ __version__ = "0.19.1"
 # flake8: noqa
 from .inline_image import InlineImage
 from .listing import Listing
-from .richtext import RichText, R
+from .richtext import RichText, R, RichTextParagraph, RP
 from .subdoc import Subdoc
 from .template import DocxTemplate
