@@ -1,12 +1,10 @@
 from docxtpl import DocxTemplate
 
-doctemplate = r'templates/doc_properties_tpl.docx'
+doctemplate = r"templates/doc_properties_tpl.docx"
 
 tpl = DocxTemplate(doctemplate)
 
-context = {
-    'test': 'HelloWorld'
-}
+context = {"test": "HelloWorld"}
 
 tpl.render(context)
 tpl.save("output/doc_properties.docx")
